pywws.ZambrettiCore — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# pywws.ZambrettiCore

Fonctions

`Zambretti` |

`pywws.ZambrettiCore.` `ZambrettiCode`(pressure, month, wind, trend, north=True, baro_top=1050.0, baro_bottom=950.0)

  Mise en œuvre simple de l’algorithme de prévision Zambretti. Inspiré par algorithme Java de beteljuice.com, telle que convertie en Python par honeysucklecottage.me.uk, et d’autres informations à partir de http://www.meteormetrics.com/zambretti.htm

`pywws.ZambrettiCore.` `ZambrettiText`(letter)

`pywws.ZambrettiCore.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »